Learn R Programming

MexBrewer (version 0.0.2)

MexBrewer-package: MexBrewer: Color Palettes Inspired by Works of Mexican Painters and Muralists

Description

Color palettes inspired by the works of Mexican painters and muralists. The package includes functions that return vectors of colors and also functions to use color and fill scales in 'ggplot2' visualizations.

Arguments

Author

Maintainer: Antonio Páez paezha@mcmaster.ca (ORCID)

See Also