Sets order of colors. Default palette is 1. If direction is -1, palette color order is reversed
override.order
Colors are picked from palette to maximize readability and aesthetics. This means
that colors are not always selected in sequential order from the full palette. If override.order is set to TRUE,
colors are selected in sequential order from the full palette instead. Default is FALSE.