Learn R Programming

MexBrewer (version 0.0.2)

mex.brewer: Mex Palette Generator

Description

These are a handful of color palettes from Mexican muralists. Complete list of palette colors and the works that inspired them can be found here.

Usage

mex.brewer(
  palette_name,
  n,
  type = c("discrete", "continuous"),
  direction = c(1, -1),
  override.order = FALSE
)

Value

A vector of colors for use in visualization tasks

Arguments

palette_name

Name of Palette. Choices are: Alacena, Atentado, Aurora, Casita1, Casita2, Casita3, Concha, Frida, Huida, Maiz, Naturaleza,Ofrenda, Revolucion, Ronda, Taurus1, Taurus2,Tierra, Vendedora.

n

Number of desired colors. If number of requested colors is beyond the scope of the palette, colors are automatically interpolated. If n is not provided, the length of the palette is used.

type

Either "continuous" or "discrete". Use continuous if you want to automatically interpolate between colors.

direction

Sets order of colors. Default palette is 1. If direction is -1, palette color order is reversed

override.order

Colors are picked from palette to maximize readability and aesthetics. This means that colors are not always selected in sequential order from the full palette. If override.order is set to TRUE, colors are selected in sequential order from the full palette instead. Default is FALSE.

Examples

Run this code
mex.brewer("Atentado")

mex.brewer("Concha", 6)

mex.brewer("Frida", 10, "continuous")

Run the code above in your browser using DataLab