- region
INEGI code of the state
- state_name
short state name (e.g. Coahuila)
- state_name_official
Official state name (e.g. Coahuila de Zaragoza)
- state_abbr
state abbreviation
- state_abbr_official
official state abbreviation (it can be awkward to use Chis for Chiapas)
according to the INEGI.
- year
2015, the year of the Conteo from which the data is sourced
- pop
total state population according to the Censo 2020
- pop_male
male population according to the Censo 2020
- pop_female
female population according to the Censo 2020
- afromexican
afromexican population according to the Censo 2020
- indigenous_language
Number of persons who speak an indigenous language according to the Censo 2020